<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="65"/>
        <source>alarms in next %1 h</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="161"/>
        <source>d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="219"/>
        <source>--:--</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="38"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="68"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="86"/>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="103"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="110"/>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="132"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="149"/>
        <source>Alarms only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Alarms + Calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="159"/>
        <source>All Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="167"/>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="193"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="222"/>
        <source>recurrent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="229"/>
        <source>Frame (h)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="251"/>
        <source>Time Remain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="270"/>
        <source>Header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="282"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="294"/>
        <source>Show empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="307"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="314"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="118"/>
        <source>Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="119"/>
        <source>Developed with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="120"/>
        <source>Desktop widget, showing time of next alarms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="121"/>
        <source>Send reports to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="128"/>
        <source>About Next Alarm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
